%****************************************************************
%        Hochschule Hamm-Lippstadt                              *
%****************************************************************
% Modul           : ReadSensors_master                          *
%                                                               *
% Datum           : 16-Jan-2019                                 *
%                                                               *
% Funktion        : Sensordaten abfragen                        *
%                                                               *
%                                                               *
% Implementation  : MATLAB R2018b                               *
%                                                               *
%                                                               *
% Author          : Dennis Brker                               *
%                                                               *
%                                                               *
% Bemerkung       : Die Software verwendet SourceCode           *
%                   von https://github.com/sid5291/             *
%                   SensorTag-Matlab                            *
%                                                               *
% Letzte nderung : 17-Feb-2019                                 *
%                                                               *
%***************************************************************/


function GetSensorData(data_type)
    READ_TYPE = 4;
    SCALE_LSB = 0.03125;
    global TempSensor;
    global HumidSensor;
    global PressSensor;
    global OptSensor;
    GATT_ReadIRTemp = ['01'; '8A'; 'FD'; '04'; '00'; '00'; '24'; '00'];
    GATT_ReadHumid = ['01'; '8A'; 'FD'; '04'; '00'; '00'; '2C'; '00'];
    GATT_ReadBar = ['01'; '8A'; 'FD'; '04'; '00'; '00'; '34'; '00'];
    GATT_ReadOptical = ['01'; '8A'; 'FD'; '04'; '00'; '00'; '44'; '00'];

    %% Temp Data calculation
    if (data_type == 1)
        [result_data] = HCI_TXRX(GATT_ReadIRTemp,READ_TYPE);
        TempSensor = [0,0];
        rawObjTemp = hex2dec([result_data(2,:), result_data(1,:)]);
        rawObjTemp = typecast(uint16(rawObjTemp), 'int16');
        it = bitshift(rawObjTemp,-2,'int16');
        t = double(it)*SCALE_LSB;
        TempSensor(1,1) = t;
        
        rawAmbTemp = hex2dec([result_data(4,:), result_data(3,:)]);
        rawAmbTemp = typecast(uint16(rawAmbTemp), 'int16');
        it = bitshift(rawAmbTemp,-2,'int16');
        t = double(it)*SCALE_LSB;
        TempSensor(2,1) = t;
    end
    
    %% Humidity Data
    if (data_type == 2)
        [result_data] = HCI_TXRX(GATT_ReadHumid,READ_TYPE);
        HumidSensor = [0,0];
        rawTemp = hex2dec([result_data(2,:), result_data(1,:)]);
        rawTemp = typecast(uint16(rawTemp), 'uint16');
        temp = double(typecast(uint16(rawTemp), 'int16'))/65536*165 - 40;
        HumidSensor(1,1) = temp;

        rawHum = hex2dec([result_data(4,:), result_data(3,:)]);
        rawHum = typecast(uint16(rawHum), 'uint16');
        A = ['00', '03'];
        A = bitcmp(hex2dec(A), 'uint16');
        rawHum = bitand(rawHum, A);
        hum = double(rawHum)/65536*100;
        HumidSensor(2,1) = hum;
    end
    
    %% Barometer Data
    if (data_type == 3)
        [result_data] = HCI_TXRX(GATT_ReadBar,READ_TYPE);
        PressSensor = [0,0];
        %rawTempPress = hex2dec([result_data(3,:), result_data(2,:), result_data(1,:)]);
        %TempPress = double(uint32(rawTempPress))/100;
        %PressSensor(1,1) = TempPress;
        rawPress = hex2dec([result_data(4,:), result_data(3,:), result_data(2,:)]);
        Press = double(uint32(rawPress))/100;
        PressSensor(2,1) = Press;
    end
    
    %% Optical Data
    if (data_type == 4)
        [result_data] = HCI_TXRX(GATT_ReadOptical,READ_TYPE);
        rawOptic = hex2dec([result_data(4,:), result_data(3,:)]);
        rawOptic = typecast(uint16(rawOptic), 'uint16');
        m = bitand(uint16(rawOptic),uint16(hex2dec('0FFF')),'uint16');
        e = bitand(uint16(rawOptic),uint16(hex2dec('F000')),'uint16');
        e = bitshift(e,-12,'uint16');
        if (e == 0)
            e = 1;
        else
            e = bitshift((e-1),2,'uint16');
        end
        OptSensor(1,1) = double(m)*(0.01*double(e));
    end    
end
