%****************************************************************
%        Hochschule Hamm-Lippstadt                              *
%****************************************************************
% Modul           : ReadSensors_master                          *
%                                                               *
% Datum           : 16-Jan-2019                                 *
%                                                               *
% Funktion        : Senden und Empfangen von BLE-Daten          *
%                                                               *
%                                                               *
% Implementation  : MATLAB R2018b                               *
%                                                               *
%                                                               *
% Author          : Dennis Brker                               *
%                                                               *
%                                                               *
% Bemerkung       : Die Software verwendet SourceCode           *
%                   von https://github.com/sid5291/             *
%                   SensorTag-Matlab sowie von                  *
%                   Tolga Bozer & Lukas Ranzinger               *
%                                                               *
% Letzte nderung : 14-Feb-2019                                 *
%                                                               *
%***************************************************************/

function [result] = HCI_TXRX(data,type)
global COMPORT;
global DisplayHex;
ADDRESS_TYPE  = 1;
if(nargin < 2)
    type = 0;
end

%% Open Serial Port
s = serial(COMPORT); %Set COM-Port
set(s,'BaudRate',115200,'Timeout',10,'FlowControl','none','Parity','none'); %Set COM-Port settings
result = 0;

dec=hex2dec(data);
fopen(s);
%% Write data
if(DisplayHex == 0)
    disp('Send:');
    Hex_disp(data);
    fprintf('\n');
end
fwrite(s,char(dec)');

%% Read data
if(type == 1) % Device scan
    temp_h = dec2hex(0,2);
    i = 1;
    while (1)
        temp = fread(s,1);
        if(isempty(temp))
            continue;
        end
        temp_h = [temp_h; dec2hex(temp,2)];
        i =i+1;
        if(strcmp(temp_h(i-1,:),'01') && strcmp(temp_h(i,:),'06'))% Discovery Done
            break;
        end
    end
end
tic;
while(toc < 2)
end
[A,count] = fread(s);
fclose(s);
h=dec2hex(A);
if(DisplayHex == 0)
    disp('Received:');
    Hex_disp(h);
    fprintf('\n');
end
if(type==1)
    h = [temp_h;h];
end
i = 1;
while(i<=length(h) && result == 0)
    if(h(i,:) == '04') %Type: Event
        data_length = hex2dec(h(i+2,:));
        i = i+3;
        payload = h(i:(data_length+i-1),:);
        i = i + (data_length-1);
        if(payload(3,:) == '00') %Status: Success
            if(strcmp(payload(1,:),'1B') && strcmp(payload(2,:),'05')) % Already configured
                result = -1;
            elseif(type == 1) % Device scan
                if(strcmp(payload(1,:),'01') && strcmp(payload(2,:),'06')) % Discovery Done
                    disp('Discovery Done')
                    devices = hex2dec(payload(4,:));
                    fprintf('Number of Devices %d\n',devices);
                    disp('Addresses');
                    size = length(payload);
                    for m = 1:devices
                        address = payload(size-5:size,:); % 6 byte MAC Address
                        fprintf('Device %d MAC Address(reversed):\n',m);
                        Hex_disp(address,ADDRESS_TYPE)
                        size = size - 8;
                    end
                end
            elseif(type == 4) % Read data
                if(strcmp(payload(1,:),'0B') && strcmp(payload(2,:),'05'))  % GATT_ReadRsp
                    result = payload((length(payload)-3):length(payload),:);
                end
            end
        elseif(payload(3,:)== '12')
            disp('Not in Correct State')
        elseif(payload(3,:) == '11')
            disp('Already Performing task')
        else
            disp ('Error')
        end
    end
    i=i+1;
end
end

