%****************************************************************
%        Hochschule Hamm-Lippstadt                              *
%****************************************************************
% Modul           : ReadSensors_master                          *
%                                                               *
% Datum           : 14-Jan-2019                                 *
%                                                               *
% Funktion        : Auslesen von Sensordaten                    *
%                                                               *
%                                                               *
% Implementation  : MATLAB R2018b                               *
%                                                               *
%                                                               *
% Author          : Dennis Brker                               *
%                                                               *
%                                                               *
% Bemerkung       : Die Software verwendet SourceCode           *
%                   von https://github.com/sid5291/             *
%                   SensorTag-Matlab sowie von                  *
%                   Tolga Bozer & Lukas Ranzinger               *
%                                                               *
% Letzte nderung : 17-Feb-2019                                 *
%                                                               *
%***************************************************************/

% Initialisierung von Matlab
clear all
close all
clc
warning('off')

%% Globale Variablen
global COMPORT
global TempSensor;
global HumidSensor;
global PressSensor;
global OptSensor;
global DisplayHex;
DisplayHex = 0;
COMPORT = 'COM3';
interval = 60; %Intervall fr das Abrufen der Daten

n = 0;
hold on;
READ_TYPE = 4;

%% Initialisierung
initializeSensortag()
TempSensor = zeros(2,1);
HumidSensor = zeros(2,1);
PressSensor = zeros(2,1);
OptSensor = zeros(1,1);
SensorData = zeros(9,1);
        
%Read Battery Level
[Batt_result] = HCI_TXRX(['01'; '8A'; 'FD'; '04'; '00'; '00'; '1E'; '00'],READ_TYPE);
Level = [Batt_result(4,:)];
disp('Battery Level (recommended >60%):');
Battery = [num2str(hex2dec(Level)),'%'];
disp(Battery);

%% Zyklusschleife
while 1
    %Send/Receive Benachrichtigung deaktivieren
    DisplayHex = 1;
    
    disp('Getting Sensor Values...');
    n = n + 1;
    GetSensorData(1);
    GetSensorData(2);
    GetSensorData(3);
    GetSensorData(4);
    d = datestr(now);
    SensorData(n,1:8) = [n, TempSensor(1,1), TempSensor(2,1) HumidSensor(1,1), HumidSensor(2,1), PressSensor(1,1), PressSensor(2,1), OptSensor(1,1)];
    %Fortlaufende Nummerierung
    if (n<10)
        Time(n,:) = ['00',num2str(n),'   ', d];
    else
        if (n<100)
            Time(n,:) = ['0',num2str(n),'   ', d];
        else    
            Time(n,:) = [num2str(n),'   ', d];
        end
    end
    
    Messung = SensorData(:,1);
    IRTemperatur = SensorData(:,2);
    Umgebungstemperatur = SensorData(:,3);
    Lufttemperatur = SensorData(:,4);
    Luftfeuchtigkeit = SensorData(:,5);
    %BarometerTemp = SensorData(:,6);
    Druck = SensorData(:,7);
    Helligkeit = SensorData(:,8);
    T = table(Messung,IRTemperatur,Umgebungstemperatur,Lufttemperatur, Luftfeuchtigkeit, Druck, Helligkeit)
    save('Time.mat', 'Time');
    writetable(T, 'SensorValues.csv', 'WriteRowNames', true);

    subplot(4,2,1);
    plot(SensorData(1:n,1),SensorData(1:n,2));
    xlabel('Messung n');
    ylabel('x in C');
    title('Infrarot-Temperatur');
    
    subplot(4,2,2);
    plot(SensorData(1:n,1),SensorData(1:n,3));
    xlabel('Messung n');
    ylabel('x in C');
    title('Umgebungs-Temperatur');
    
    subplot(4,2,3);
    plot(SensorData(1:n,1),SensorData(1:n,4));
    xlabel('Messung n');
    ylabel('x in C');
    title('Lufttemperatur');
    
    subplot(4,2,4);
    plot(SensorData(1:n,1),SensorData(1:n,5));
    xlabel('Messung n');
    ylabel('x in %');
    title('Luftfeuchtigkeit');
    
    subplot(4,2,5);
    plot(SensorData(1:n,1),SensorData(1:n,7));
    xlabel('Messung n');
    ylabel('x in hPa');
    title('Luftdruck');
    
    subplot(4,2,7);
    plot(SensorData(1:n,1),SensorData(1:n,8));
    xlabel('Messung n');
    ylabel('x in LUX');
    title('Helligkeit');
    drawnow;
    
    pause(interval);
end
