%****************************************************************
%        Hochschule Hamm-Lippstadt                              *
%****************************************************************
% Modul           : ReadSensors_master                          *
%                                                               *
% Datum           : 24-Jan-2019                                 *
%                                                               *
% Funktion        : Initialisierung des Sensortags              *
%                                                               *
%                                                               *
% Implementation  : MATLAB R2018b                               *
%                                                               *
%                                                               *
% Author          : Dennis Brker                               *
%                                                               *
%                                                               *
% Bemerkung       : Die Software verwendet SourceCode           *
%                   von https://github.com/sid5291/             *
%                   SensorTag-Matlab                            *
%                                                               * 
%                                                               *
% Letzte nderung : 17-Jan-2019                                 *
%                                                               *
%***************************************************************/

function initializeSensortag()
instrreset; %Reset COM-Ports

%%Variable declaration
GAP_initialise=['01';'00';'FE';'26';'08';'05';'00';'00';'00';'00';'00';'00';'00'
    '00';'00';'00';'00';'00';'00';'00';'00';'00';'00';'00';'00';'00'
    '00';'00';'00';'00';'00';'00';'00';'00';'00';'00';'00';'00';'01'
    '00';'00';'00'];
GAP_DeviceDiscovery = ['01';'04';'FE';'03';'03';'01';'00'];
SCAN_TYPE = 1;
%Change mac adress
GAP_connect = ['01'; '09'; 'FE'; '09'; '00'; '00'; '00' ;'07';'3C'; 'F7' ;'22' ;'91' ;'B0'];  %B0:91:22:F7:3C:07

% -Type           : 0x01 (Command)
% -OpCode         : 0xFE09 (GAP_EstablishLinkRequest)
% -Data Length    : 0x09 (9) byte(s)
%  HighDutyCycle  : 0x00 (0) (Disable)
%  WhiteList      : 0x00 (0) (Disable)
%  AddrTypePeer   : 0x00 (0) (Public)
%  MacAdress      : B0:B4:48:B9:45:86 (Reverse Order)


CONNECT_TYPE = 2;
% Reference http://processors.wiki.ti.com/images/a/a8/BLE_SensorTag_GATT_Server.pdf
GATT_IRTempOn = ['01'; '92'; 'FD'; '05'; '00'; '00'; '27'; '00'; '01'];
GATT_IRTempOff = ['01'; '92'; 'FD'; '05'; '00'; '00'; '27'; '00'; '00'];
GATT_HumidOn = ['01'; '92'; 'FD'; '05'; '00'; '00'; '2F'; '00'; '01'];
GATT_HumidOff = ['01'; '92'; 'FD'; '05'; '00'; '00'; '2F'; '00'; '00'];
GATT_BarOn = ['01'; '92'; 'FD'; '05'; '00'; '00'; '37'; '00'; '01'];
GATT_BarOff = ['01'; '92'; 'FD'; '05'; '00'; '00'; '37'; '00'; '00'];
GATT_OpticOn = ['01'; '92'; 'FD'; '05'; '00'; '00'; '47'; '00'; '01'];
GATT_OpticOff = ['01'; '92'; 'FD'; '05'; '00'; '00'; '47'; '00'; '00'];

%GATT_IRTempNotifyOn = ['01'; '92'; 'FD'; '06'; '00'; '00'; '22'; '00'; '01'; '00'];
%GATT_IRTempNotifyOff = ['01'; '92'; 'FD'; '06'; '00'; '00'; '22'; '00'; '00'; '00'];
%GATT_HumidNotifyOn = ['01'; '92'; 'FD'; '06'; '00'; '00'; '2A'; '00'; '01'; '00'];
%GATT_HumidNotifyOff = ['01'; '92'; 'FD'; '06'; '00'; '00'; '2A'; '00'; '00'; '00'];
%GATT_BarNotifyOn = ['01'; '92'; 'FD'; '06'; '00'; '00'; '32'; '00'; '01'; '00'];
%GATT_BarNotifyOff = ['01'; '92'; 'FD'; '06'; '00'; '00'; '32'; '00'; '00'; '00'];
%GATT_OpticNotifyOn = ['01'; '92'; 'FD'; '06'; '00'; '00'; '42'; '00'; '01'; '00'];
%GATT_OpticNotifyOff = ['01'; '92'; 'FD'; '06'; '00'; '00'; '42'; '00'; '00'; '00'];

WRITE_TYPE = 3;
READ_TYPE = 4;
NOTIFY_TYPE = 5;
k = 0;
doinit = 0;
doinit = input('Initialize Sensortag ? (n to skip)','s');
if isempty(doinit)
    doinit = 'y';
end
if(doinit ~= 'n')
    
    disp('Going to Initialize');
    status = HCI_TXRX(GAP_initialise);

    if status ~= -1 %Already configured
        %%Scan for devices
        disp('Going to Scan');
        disp('Make Sure Led D1 is blinking on Sensor Tag');
        HCI_TXRX(GAP_DeviceDiscovery,SCAN_TYPE);
    
        %%Connect with SensorTag
        disp('Going to Connect to Sensor Tag');
        disp('LED D1 will turn off when Connected, if doesnt there is an error');
        HCI_TXRX(GAP_connect,CONNECT_TYPE);       
    
        %%Config Temp Sensor
        disp('Going to Config IR Temp Sensor');
        HCI_TXRX(GATT_IRTempOn,WRITE_TYPE);
        %HCI_TXRX(GATT_IRTempPeriod,WRITE_TYPE);

        %Config Humidity Sensor
        disp('Going to Config Humidity Sensor');
        HCI_TXRX(GATT_HumidOn,WRITE_TYPE);
        %HCI_TXRX(GATT_HumidPeriod,WRITE_TYPE);
        
        %Config Barometer Sensor
        disp('Going to Config Barometer Sensor');
        HCI_TXRX(GATT_BarOn,WRITE_TYPE);
        
        %Config Optical Sensor
        disp('Going to Config Optical Sensor');
        HCI_TXRX(GATT_OpticOn,WRITE_TYPE);

        %Turn Notifications On
        %disp('Going to Turn Notifications On');
        %HCI_TXRX(GATT_IRTempNotifyOn,WRITE_TYPE);
        %HCI_TXRX(GATT_HumidNotifyOn,WRITE_TYPE);
        %HCI_TXRX(GATT_BarNotifyOn,WRITE_TYPE);
        
    end
end